# Session 4 - Data visualization with ggplot
# Willa & Elena
# July 27, 2021

#### Set up and load packages #### 
library(tidyverse)
options(stringsAsFactors=FALSE)

#### Warm-up  #### 

## 1. Load in penguins_wide dataset and view your data. Anything diffefrent you notice about the observations this time? 


## 2 Use tidyverse commands to do the following data processing steps (use pipes to connect your commands). 
    # 2a. Remove three columns: "bill_length_mm", "bill_depth_mm", "flipper_length_mm".
    # 2b. Remove NAs from the dataset



#### End of Warm-up ####

#### Data Viz demo ####

### Plot 1 : Let's compare the body mass of each penguin species in 2007.

# 1a. Set up our ggplot

  
 # add a column object
 #  notice that the species are ordered alphabetically. We could change this by creating an ordered factor
# eg. factor(species, levels = c("Chinstrap", "Adelie", "Gentoo"))



# 1b. Now lets separate the the plot by sex. 




## Bar charts aren't the best way to look at data because it doesn't tell us much about individual data points or the distribution of data. 


# 1c. Let's use a box plot. 



## This gives us some more descriptive stats about the data but we still don't
## have a good feel for what the distribution of the data points look like.

# 1d. Lets use a violin plot to visualize the data. 

  


## A violin plot immediately gives us an idea of the shape of our data. We also
## see that while the mean mass of males and females may be similar the
## distributions can be quite different.

# 1e. Now that we are happy with our plot choice, lets customize it further.

  
  # change axis labels



  # change the y axis scale to start at 0 and end at 8000
 
  
  # change the color scheme. There are a few ways to do this:
  # i.Some color names are built in
 
  # ii.We can give it hex values
  
  # iii, We can use color palettes

  
  # change the overall theme
  


#### Plot 2. Now lets look at the relationship between body mass in 2007 and 2008 
#### for each species

ggplot(penguins_clean, aes(x = body_mass_g_2007, y = body_mass_g_2008)) + 
  
  # add a scatter plot
  
  
  # add a regression line
 
  
  # split by species
  

# This gives us an idea of the relationship between these two measures
# But what if we want to compare body mass between 2007 and 2008 for each species
# As we did for sex to see if there are differences in body mass between 2007 and 2008? 

ggplot(penguins_clean, aes())

#### Data reshaping ####

# The way our data is now, we can't make a violin plot that compares body mass
# in 2007 to body mass in 2008!

# Why's that? It's because we have the data for each of those years in separate
# columns. However, we want to GROUP by year, like we did for sex. And right
# now, we don't have a variable (i.e., a column) that is good for grouping by year.

# The columns we have now, are good for an axis (e.g., y-axis in the previous
# plot, or for making a scatter plot comparing 2007 to 2008)

# So, in order to group by year in our violin plot, we need to 'reshape' the data
# This means that we need to change the way the rows and columns are so that we
# have a column that is good for grouping by year.
# In other words, we want to have a data frame that has a column that indicates
# year, and a column that is for body mass. So there will now be two rows per
# penguin: one row for 2007 and one row for 2008.


# This is what we want our data to look like


# How do we get there?
# We need to use a function called pivot_longer(), to pivot (i.e., reshape, rearrange) our data to be longer (i.e., have more rows)




# We can "undo" what we just did, too! Using the sister function pivot_wider


#### Data vis cont. #### 
### Now lets make the plot comparing body mass between years. 

ggplot(penguins_long, aes(x = , y = , fill = )) + 
  geom_violin() + 
  
  # change axis labels
  labs(title = 'body mass by species across years', 
       x = "Species", 
       y = " Body mass (g)") + 
  
  # change the y axis scale to start at 0 
  ylim(0, 8000) +
  
  # change the color scheme
  scale_fill_brewer(palette="RdBu") + # use a color palette
  
  # change the overall theme
  theme_bw() 
  






